@@ -1,5 +1,6 @@
 __author__ = 'dkador'
 
+
 class BaseKeenClientError(Exception):
     """
     Base class for all Keen Client errors.
@@ -9,11 +10,13 @@ class BaseKeenClientError(Exception):
         # all sub-classes should set self._message in their initializers
         return self._message
 
+
 class InvalidProjectIdError(BaseKeenClientError):
-    def __init__(self, project_token):
-        super(InvalidProjectIdError, self).__init__(project_token)
-        self.project_token = project_token
-        self._message = "Invalid project token: {}".format(project_token)
+    def __init__(self, project_id):
+        super(InvalidProjectIdError, self).__init__(project_id)
+        self.project_id = project_id
+        self._message = "Invalid project id: {0}".format(project_id)
+
 
 class InvalidPersistenceStrategyError(BaseKeenClientError):
     def __init__(self):
@@ -21,11 +24,12 @@ class InvalidPersistenceStrategyError(BaseKeenClientError):
         self._message = "Invalid persistence strategy. A persistence strategy" \
                         " must be an instance of BasePersistenceStrategy."
 
+
 class KeenApiError(BaseKeenClientError):
     def __init__(self, api_error):
         super(KeenApiError, self).__init__(api_error)
         self.api_error = api_error
-        self._message = "Error from Keen API. Details:\n Message: {}\nCode: "\
-                        "{}".format(
+        self._message = "Error from Keen API. Details:\n Message: {0}\nCode: " \
+                        "{1}".format(
             api_error["message"], api_error["error_code"]
         )
\ No newline at end of file
